[SCM] Vim packaging branch, master, updated. debian/7.2.025-2-50-g2fef531

James Vega jamessan at debian.org
Wed Nov 26 09:20:49 UTC 2008


The following commit has been merged in the master branch:
commit bc1cc74160237e9bd83719b0b55bf48ce49490ee
Merge: 6dc29b08a6955133972f8b150c57ba2288c6ea34 b075aeef6c7defc6c77331ffd38cf807cc0da441
Author: James Vega <jamessan at debian.org>
Date:   Tue Nov 25 20:54:41 2008 -0500

    Merge branch 'deb/pythonpath'
    
    Conflicts:
    	src/normal.c
    
    Signed-off-by: James Vega <jamessan at debian.org>

diff --combined src/option.c
index da542e0,e8b8b0c..0c52ea4
--- a/src/option.c
+++ b/src/option.c
@@@ -2593,13 -2593,13 +2593,13 @@@ static struct vimoptio
  #ifdef FEAT_VIMINFO
  			    (char_u *)&p_viminfo, PV_NONE,
  #if defined(MSDOS) || defined(MSWIN) || defined(OS2)
- 			    {(char_u *)"", (char_u *)"'20,<50,s10,h,rA:,rB:"}
+ 			    {(char_u *)"", (char_u *)"'100,<50,s10,h,rA:,rB:"}
  #else
  # ifdef AMIGA
  			    {(char_u *)"",
- 				 (char_u *)"'20,<50,s10,h,rdf0:,rdf1:,rdf2:"}
+ 				 (char_u *)"'100,<50,s10,h,rdf0:,rdf1:,rdf2:"}
  # else
- 			    {(char_u *)"", (char_u *)"'20,<50,s10,h"}
+ 			    {(char_u *)"", (char_u *)"'100,<50,s10,h"}
  # endif
  #endif
  #else
@@@ -10128,7 -10128,7 +10128,7 @@@ langmap_set(
  {
      char_u  *p;
      char_u  *p2;
 -    int	    from, to;
 +    int	    from=NUL, to=NUL;
  
      langmap_init();			    /* back to one-to-one map first */
  
@@@ -10146,11 -10146,6 +10146,11 @@@
  	    p2 = NULL;	    /* aAbBcCdD form, p2 is NULL */
  	while (p[0])
  	{
 +	    if (p[0] == ',')
 +	    {
 +		++p;
 +		break;
 +	    }
  	    if (p[0] == '\\' && p[1] != NUL)
  		++p;
  #ifdef FEAT_MBYTE
@@@ -10161,29 -10156,23 +10161,29 @@@
  	    if (p2 == NULL)
  	    {
  		mb_ptr_adv(p);
 -		if (p[0] == '\\')
 -		    ++p;
 +		if (p[0] != ',')
 +		{
 +		    if (p[0] == '\\')
 +			++p;
  #ifdef FEAT_MBYTE
 -		to = (*mb_ptr2char)(p);
 +		    to = (*mb_ptr2char)(p);
  #else
 -		to = p[0];
 +		    to = p[0];
  #endif
 +		}
  	    }
  	    else
  	    {
 -		if (p2[0] == '\\')
 -		    ++p2;
 +		if (p2[0] != ',')
 +		{
 +		    if (p2[0] == '\\')
 +			++p2;
  #ifdef FEAT_MBYTE
 -		to = (*mb_ptr2char)(p2);
 +		    to = (*mb_ptr2char)(p2);
  #else
 -		to = p2[0];
 +		    to = p2[0];
  #endif
 +		}
  	    }
  	    if (to == NUL)
  	    {

diff --combined src/main.c
index dbdbfe7,a091165..7ebfbf4
--- a/src/main.c
+++ b/src/main.c
@@@ -87,9 -87,6 +87,9 @@@ typedef struc
  #ifdef FEAT_DIFF
      int		diff_mode;		/* start with 'diff' set */
  #endif
 +#ifdef SYS_TINYRC_FILE
 +    int		vi_mode;		/* started as "vi" */
 +#endif
  } mparm_T;
  
  /* Values for edit_type. */
@@@ -648,11 -645,12 +648,12 @@@ mai
  
  #ifdef FEAT_VIMINFO
      /*
       * Read in registers, history etc, but not marks, from the viminfo file
       */
      if (*p_viminfo != NUL)
      {
- 	read_viminfo(NULL, TRUE, FALSE, FALSE);
+ 	read_viminfo(NULL, VIF_WANT_INFO | VIF_GET_OLDFILES);
  	TIME_MSG("reading viminfo");
      }
  #endif
@@@ -1478,10 -1476,6 +1479,10 @@@ parse_command_name(parmp
      }
      else if (STRNICMP(initstr, "vim", 3) == 0)
  	initstr += 3;
 +#ifdef SYS_TINYRC_FILE
 +    else if (STRNICMP(initstr, "vi", 2) == 0)
 +	parmp->vi_mode = TRUE;
 +#endif
  
      /* Catch "[r][g]vimdiff" and "[r][g]viewdiff". */
      if (STRICMP(initstr, "diff") == 0)
@@@ -1516,7 -1510,8 +1517,8 @@@
  early_arg_scan(parmp)
      mparm_T	*parmp;
  {
- #if defined(FEAT_XCLIPBOARD) || defined(FEAT_CLIENTSERVER)
+ #if defined(FEAT_XCLIPBOARD) || defined(FEAT_CLIENTSERVER) \
+ 	|| !defined(FEAT_NETBEANS_INTG)
      int		argc = parmp->argc;
      char	**argv = parmp->argv;
      int		i;
@@@ -1588,6 -1583,14 +1590,14 @@@
  	else if (STRICMP(argv[i], "--echo-wid") == 0)
  	    echo_wid_arg = TRUE;
  # endif
+ # ifndef FEAT_NETBEANS_INTG
+ 	else if (strncmp(argv[i], "-nb", (size_t)3) == 0)
+         {
+             mch_errmsg(_("'-nb' cannot be used: not enabled at compile time\n"));
+             mch_exit(2);
+         }
+ # endif
+ 
      }
  #endif
  }
@@@ -2594,7 -2597,7 +2604,7 @@@ edit_buffers(parmp
  # endif
  	    (void)do_ecmd(0, arg_idx < GARGCOUNT
  			  ? alist_name(&GARGLIST[arg_idx]) : NULL,
- 			  NULL, NULL, ECMD_LASTL, ECMD_HIDE);
+ 			  NULL, NULL, ECMD_LASTL, ECMD_HIDE, curwin);
  # ifdef HAS_SWAP_EXISTS_ACTION
  	    if (swap_exists_did_quit)
  	    {
@@@ -2764,12 -2767,7 +2774,12 @@@ source_startup_scripts(parmp
  	 * Get system wide defaults, if the file name is defined.
  	 */
  #ifdef SYS_VIMRC_FILE
@@@ -648,11 -645,12 +648,12 @@@ mai
  #ifdef FEAT_VIMINFO
      /*
-      * Read in registers, history etc, but not marks, from the viminfo file
+      * Read in registers, history etc, but not marks, from the viminfo file.
+      * This is where v:oldfiles gets filled.
       */
      if (*p_viminfo != NUL)
 -	(void)do_source((char_u *)SYS_VIMRC_FILE, FALSE, DOSO_NONE);
 +# if defined(SYS_TINYRC_FILE) && defined(TINY_VIMRC)
 +	if (parmp->vi_mode)
 +	    (void)do_source((char_u *)SYS_TINYRC_FILE, FALSE, DOSO_NONE);
 +	else
 +# endif
 +	    (void)do_source((char_u *)SYS_VIMRC_FILE, FALSE, DOSO_NONE);
  #endif
  #ifdef MACOS_X
  	(void)do_source((char_u *)"$VIMRUNTIME/macmap.vim", FALSE, DOSO_NONE);
-- 
Vim packaging



More information about the pkg-vim-maintainers mailing list